==> vtigercrm-5.0.3.tgz: vtigercrm/modules/Potentials/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Potentials/language/en_us.lang.php,v 1.18 2005/04/28 14:05:53 ray Exp $
 * Description:  Defines the English language pack for the Account module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Potentials',
'LBL_MODULE_TITLE'=>'Potentials: Home',
'LBL_SEARCH_FORM_TITLE'=>'Potential Search',
'LBL_LIST_FORM_TITLE'=>'Potential List',
'LBL_OPPORTUNITY_NAME'=>'Potential Name:',
'LBL_OPPORTUNITY'=>'Potential:',
'LBL_NAME'=>'Potential Name',
'LBL_INVITEE'=>'Contacts',
'LBL_LIST_OPPORTUNITY_NAME'=>'Potential',
'LBL_LIST_ACCOUNT_NAME'=>'Account Name',
'LBL_PRODUCT_NAME'=>'Product Name',
'LBL_LIST_AMOUNT'=>'Amount',
'LBL_LIST_DATE_CLOSED'=>'Expected Close',
'LBL_LIST_SALES_STAGE'=>'Sales Stage',

'LBL_OPPORTUNITY_NAME'=>'Potential Name:',
'LBL_ACCOUNT_NAME'=>'Account Name:',
'LBL_AMOUNT'=>'Amount:',
'LBL_DATE_CLOSED'=>'Expected Close Date:',
'LBL_TYPE'=>'Type:',
'LBL_NEXT_STEP'=>'Next Step:',
'LBL_LEAD_SOURCE'=>'Lead Source:',
'LBL_SALES_STAGE'=>'Sales Stage:',
'LBL_PROBABILITY'=>'Probability (%):',
'LBL_DESCRIPTION'=>'Description:',
'LBL_OPPORTUNITY_INFORMATION'=>'Potential Information:',
'LBL_DESCRIPTION_INFORMATION'=>'Description Information:',
'LBL_CUSTOM_INFORMATION'=>'Custom Information',

'LBL_NEW_FORM_TITLE'=>'New Potential',

'ERR_DELETE_RECORD'=>"A record number must be specified to delete the opportunity.",
'LBL_TOP_OPPORTUNITIES'=>"My Top Open Potentials",

'NTC_REMOVE_OPP_CONFIRMATION'=>'Are you sure you want to remove this contact from this opportunity?',

'NTC_NONE_SCHEDULED'=>'None scheduled.',

'LBL_SELECT_OPPOPTUNITY'=>'Select Potential',
'LBL_GENERAL_INFORMATION'=>'General Information',



//for v4 release added
'LBL_NEW_POTENTIAL'=>'New Potential',
'LBL_POTENTIAL_TITLE'=>'Potentials',

'LBL_NEW_TASK'=>'New Task',
'LBL_TASK_TITLE'=>'Tasks',
'LBL_NEW_CALL'=>'New Call',
'LBL_CALL_TITLE'=>'Calls',
'LBL_NEW_MEETING'=>'New Meeting',
'LBL_MEETING_TITLE'=>'Meetings',
'LBL_NEW_EMAIL'=>'New Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_NOTE'=>'New Note',
'LBL_NOTE_TITLE'=>'Notes',

'LBL_NEW_ATTACHMENT'=>'New Attachment',
'LBL_ATTACHMENT_TITLE'=>'Attachments',

'LBL_NEW_CONTACT'=>'New Contact',
'LBL_CONTACT_TITLE'=>'Contacts',

//Added vtiger_fields after RC1 - Release
'LBL_ALL'=>'All',
'LBL_WON'=>'Won',
'LBL_LOST'=>'Lost',
'LBL_VALUE_PROPOSITION'=>'Value Proposition',
'LBL_PROSPECTING'=>'Prospecting',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Potential Tools',
//Added for 4GA
'Potential Name'=>'Potential Name',
'Amount'=>'Amount',
'Account Name'=>'Account Name',
'Currency'=>'Currency',
'Expected Close Date'=>'Expected Close Date',
'Opportunity Type'=>'Opportunity Type',
'Type'=>'Type',
'Next Step'=>'Next Step',
'Lead Source'=>'Lead Source',
'Sales Stage'=>'Sales Stage',
'Assigned To'=>'Assigned To',
'Probability'=>'Probability (%)',
'Campaign Source'=>'Campaign Source',
'Description'=>'Description',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
//Added for 4.2 Release -- CustomView
'Potential'=>'Potential',
'Expected Close'=>'Expected Close',

//Added for Existing Picklist Strings

'Prospecting'=>'Prospecting',
'Qualification'=>'Qualification',
'Needs Analysis'=>'Needs Analysis',
'Value Proposition'=>'Value Proposition',
'Id. Decision Makers'=>'Id. Decision Makers',
'Perception Analysis'=>'Perception Analysis',
'Proposal/Price Quote'=>'Proposal/Price Quote',
'Negotiation/Review'=>'Negotiation/Review',
'Closed Won'=>'Closed Won',
'Closed Lost'=>'Closed Lost',

'Cold Call'=>'Cold Call',
'Existing Customer'=>'Existing Customer',
'Self Generated'=>'Self Generated',
'Employee'=>'Employee',
'Partner'=>'Partner',
'Public Relations'=>'Public Relations',
'Direct Mail'=>'Direct Mail',
'Conference'=>'Conference',
'Trade Show'=>'Trade Show',
'Web Site'=>'Web Site',
'Word of mouth'=>'Word of mouth',
'Other'=>'Other',

'--None--'=>'--None--',
'Existing Business'=>'Existing Business',
'New Business'=>'New Business',



);

?>

==> vtigercrm-5.1.0.tgz: vtigercrm/modules/Potentials/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Potentials/language/en_us.lang.php,v 1.18 2005/04/28 14:05:53 ray Exp $
 * Description:  Defines the English language pack for the Account module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Potentials',
'LBL_MODULE_TITLE'=>'Potentials: Home',
'LBL_SEARCH_FORM_TITLE'=>'Potential Search',
'LBL_LIST_FORM_TITLE'=>'Potential List',
'LBL_OPPORTUNITY_NAME'=>'Potential Name:',
'LBL_OPPORTUNITY'=>'Potential:',
'LBL_NAME'=>'Potential Name',
'LBL_INVITEE'=>'Contacts',
'LBL_LIST_OPPORTUNITY_NAME'=>'Potential',
'LBL_LIST_ACCOUNT_NAME'=>'Account Name',
'LBL_PRODUCT_NAME'=>'Product Name',
'LBL_LIST_AMOUNT'=>'Amount',
'LBL_LIST_DATE_CLOSED'=>'Expected Close',
'LBL_LIST_SALES_STAGE'=>'Sales Stage',

'LBL_OPPORTUNITY_NAME'=>'Potential Name:',
'LBL_ACCOUNT_NAME'=>'Account Name:',
'LBL_AMOUNT'=>'Amount:',
'LBL_DATE_CLOSED'=>'Expected Close Date:',
'LBL_TYPE'=>'Type:',
'LBL_NEXT_STEP'=>'Next Step:',
'LBL_LEAD_SOURCE'=>'Lead Source:',
'LBL_SALES_STAGE'=>'Sales Stage:',
'LBL_PROBABILITY'=>'Probability (%):',
'LBL_DESCRIPTION'=>'Description:',
'LBL_OPPORTUNITY_INFORMATION'=>'Potential Information:',
'LBL_DESCRIPTION_INFORMATION'=>'Description Information:',
'LBL_CUSTOM_INFORMATION'=>'Custom Information',

'LBL_NEW_FORM_TITLE'=>'New Potential',

'ERR_DELETE_RECORD'=>"A record number must be specified to delete the opportunity.",
'LBL_TOP_OPPORTUNITIES'=>"My Top Open Potentials",

'NTC_REMOVE_OPP_CONFIRMATION'=>'Are you sure you want to remove this contact from this opportunity?',

'NTC_NONE_SCHEDULED'=>'None scheduled.',

'LBL_SELECT_OPPOPTUNITY'=>'Select Potential',
'LBL_GENERAL_INFORMATION'=>'General Information',



//for v4 release added
'LBL_NEW_POTENTIAL'=>'New Potential',
'LBL_POTENTIAL_TITLE'=>'Potentials',

'LBL_NEW_TASK'=>'New Task',
'LBL_TASK_TITLE'=>'Tasks',
'LBL_NEW_CALL'=>'New Call',
'LBL_CALL_TITLE'=>'Calls',
'LBL_NEW_MEETING'=>'New Meeting',
'LBL_MEETING_TITLE'=>'Meetings',
'LBL_NEW_EMAIL'=>'New Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_NOTE'=>'New Document',
'LBL_NOTE_TITLE'=>'Documents',

'LBL_NEW_ATTACHMENT'=>'New Attachment',
'LBL_ATTACHMENT_TITLE'=>'Attachments',

'LBL_NEW_CONTACT'=>'New Contact',
'LBL_CONTACT_TITLE'=>'Contacts',

//Added vtiger_fields after RC1 - Release
'LBL_ALL'=>'All',
'LBL_WON'=>'Won',
'LBL_LOST'=>'Lost',
'LBL_VALUE_PROPOSITION'=>'Value Proposition',
'LBL_PROSPECTING'=>'Prospecting',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Potential Tools',
//Added for 4GA
'Potential Name'=>'Potential Name',
'Amount'=>'Amount',
'Account Name'=>'Account Name',
'Currency'=>'Currency',
'Expected Close Date'=>'Expected Close Date',
'Opportunity Type'=>'Opportunity Type',
'Type'=>'Type',
'Next Step'=>'Next Step',
'Lead Source'=>'Lead Source',
'Sales Stage'=>'Sales Stage',
'Assigned To'=>'Assigned To',
'Probability'=>'Probability (%)',
'Campaign Source'=>'Campaign Source',
'Description'=>'Description',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
//Added for 4.2 Release -- CustomView
'Potential'=>'Potential',
'Expected Close'=>'Expected Close',

//Added for Existing Picklist Strings

'Prospecting'=>'Prospecting',
'Qualification'=>'Qualification',
'Needs Analysis'=>'Needs Analysis',
'Value Proposition'=>'Value Proposition',
'Id. Decision Makers'=>'Id. Decision Makers',
'Perception Analysis'=>'Perception Analysis',
'Proposal/Price Quote'=>'Proposal/Price Quote',
'Negotiation/Review'=>'Negotiation/Review',
'Closed Won'=>'Closed Won',
'Closed Lost'=>'Closed Lost',

'Cold Call'=>'Cold Call',
'Existing Customer'=>'Existing Customer',
'Self Generated'=>'Self Generated',
'Employee'=>'Employee',
'Partner'=>'Partner',
'Public Relations'=>'Public Relations',
'Direct Mail'=>'Direct Mail',
'Conference'=>'Conference',
'Trade Show'=>'Trade Show',
'Web Site'=>'Web Site',
'Word of mouth'=>'Word of mouth',
'Other'=>'Other',

'--None--'=>'--None--',
'Existing Business'=>'Existing Business',
'New Business'=>'New Business',

// Added after 5.0.4 GA

// Module Sequence Numbering
'Potential No' => 'Potential No',
// END

);

?>
